# Conditional imports to make it work when those packages are not available

def patch_generic_setup():

    # GS 1.3
    try:
        from Products.GenericSetup.zcml import cleanUp
        cleanUp()
    except ImportError:
        pass
    # GS 1.4
    try:
        from Products.GenericSetup.zcml import cleanUpProfiles
        from Products.GenericSetup.zcml import cleanUpImportSteps
        from Products.GenericSetup.zcml import cleanUpExportSteps
        cleanUpProfiles()
        cleanUpImportSteps()
        cleanUpExportSteps()
    except ImportError:
        pass


def patch_wicked():
    try:
        from wicked.fieldevent.meta import cleanUp
        cleanUp()
    except ImportError:
        pass


def patch_cmfcore():
    try:
        from Products.CMFCore.zcml import cleanUp
        cleanUp()
    except ImportError:
        pass


def patch_pas():
    try:
        from Products.PluggableAuthService.zcml import cleanUp
        cleanUp()
    except ImportError:
        pass



from zope.app.component.hooks import setSite
from zope.component import getGlobalSiteManager

from Products.Five import zcml

from plone.reload import PATCHES


def reload_zcml():
    gsm = getGlobalSiteManager()
    old_gsm_dict = gsm.__dict__.copy()
    try:
        setSite(None)
        gsm.__init__(gsm.__name__)
        # Apply patches
        global PATCHES
        for patch in PATCHES:
            patch()

        # Reload all ZCML
        zcml._initialized = False
        zcml._context._seen_files.clear()
        zcml.load_site()
    except Exception, e:
        gsm.__init__(gsm.__name__)
        gsm.__dict__.clear()
        gsm.__dict__.update(old_gsm_dict)
        raise e
